@@ -13,6 +13,7 @@ use DateTime::Format::Duration;
 use Cwd;
 use File::Path qw(make_path);
 use File::Spec;
+#use String::Escape qw( quote  );
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -33,7 +34,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.38';
+our $VERSION = '2.39';
 
 =head1 SYNOPSIS
 
@@ -99,7 +100,8 @@ Internal variable
 sub _set_outdir{
     my($self, $outdir) = @_;
 
-    make_path($outdir) if ! -d $outdir;
+    #make_path(quote($outdir)) if ! -d $outdir;
+    make_path($outdir) if -d $outdir;
     $outdir = File::Spec->rel2abs($outdir);
     $self->{outdir} = $outdir;
 }
@@ -133,7 +135,7 @@ has 'procs' => (
     documentation => q{Total number of running jobs allowed at any time. The command 'wait' can be used to have a variable number of children running.}
 );
 
-=head2 job_scheduler_ID
+=head2 job_scheduler_id
 
 Job Scheduler ID running the script. Passed to slurm for mail information
 
@@ -198,12 +200,14 @@ has 'cmd' => (
     traits  => ['String', 'NoGetopt'],
     is => 'rw',
     isa => 'Str',
-    lazy_build => 1,
+    #lazy_build => 1,
     required => 0,
     handles => {
         add_cmd => 'append',
         match_cmd => 'match',
-    }
+    },
+    predicate => 'has_cmd',
+    clearer => 'clear_cmd',
 );
 
 has 'counter' => (
